function estimatedLabels = rglvq_classify(Data, oModel)
%RGLVQ_classify.m 
%  Classify given data with relational GLVQ model
%
%  estimatedTrainLabels = rglvq_classify(Data, oModel);
%  trainError = mean( trainLab ~= estimatedTrainLabels );
%
% input: 
%  Data      : (m x (m+N) ) dissimilarity matrix with m training samples and N test samples
%  oModel    : trained RGLVQ model 
% 
% output    : the estimated labels
%  
% Frank-Michael Schleif
% fschleif@techfak.uni-bielefeld.de
%
% Conditions of GNU General Public License, version 2 apply.
% See file 'license-gpl2.txt' enclosed in this package.
% Programs are not for use in critical applications!
%
[m, Nm] = size(Data);
N       = Nm-m; 
estimatedLabels = oModel.vCodeLabels(argmin(determine_distance_relational_neurons_to_testdata(Data(1:m,m+1:end),Data(1:m,1:m), oModel.mAlpha)));
