function [f]  = rglvq_cost(variables, fDist,LabelEqualsPrototype)
% [f] = rglvq_cost(variables) 
% cost function of the relational generalized learning vector quantization
%
% Input:
%       variables            = [alpha_matrix] - see rglvq
%       fDist                = function pointer to distance calculation (on block)
%       LabelEqualsPrototype = N x M bool matrix - where prototype labels match datapoint labels
%
% Output:
%       f                    = cost function error current model
%
% Conditions of GNU General Public License, version 2 apply.
% See file 'license-gpl2.txt' enclosed in this package.
% Programs are not for use in critical applications!
%
% (C) Frank-Michael Schleif
% University of Bielefeld
% fschleif@techfak.uni-bielefeld.de
% 
[N,nb_prototypes] = size(LabelEqualsPrototype);
mDist             = fDist(variables)'; 

Dwrong = mDist;
Dwrong(LabelEqualsPrototype)    = realmax(class(Dwrong));   % set correct labels impossible
[distwrong ]           = min(Dwrong.'); % closest wrong

Dcorrect = mDist;
Dcorrect(~LabelEqualsPrototype) = realmax(class(Dcorrect)); % set wrong labels impossible
[distcorrect ]       = min(Dcorrect.'); % closest correct

distcorrectpluswrong = distcorrect + distwrong;
distcorrectminuswrong = distcorrect - distwrong;
mu = distcorrectminuswrong ./ distcorrectpluswrong;
f  = sum(mu);
